from django.db import models
from django.core.validators import MinLengthValidator, RegexValidator, MaxValueValidator
from django.urls import reverse
from datetime import date

class Author(models.Model):

    first_name = models.CharField(max_length=100)
    last_name = models.CharField(max_length=100)
    age = models.IntegerField()
    nationality = models.CharField(max_length=100)
    bio = models.TextField()

    def __str__(self):
        return '{} {}'.format(self.first_name, self.last_name)

    def get_absolute_url(self):
        return reverse('bookshelf:author_details', kwargs={'pk':self.pk})


class Book(models.Model):

    title = models.CharField(max_length=100)
    author = models.ForeignKey(Author,on_delete=models.CASCADE,related_name="books",default="")
    publisher = models.CharField(max_length=100)
    year_published = models.PositiveIntegerField(validators=[MaxValueValidator(date.today().year)])
    ISBN = models.CharField(primary_key=True, max_length=13,validators=[MinLengthValidator(13), RegexValidator('^(\d{13})$')])
    blurb = models.CharField(max_length=200, validators=[MinLengthValidator(100)])

    def __str__(self):
        return '{}'.format(self.title)

    def get_absolute_url(self):
        return reverse("bookshelf:book_details",kwargs={'pk':self.pk})
